pub struct VolumeLimiter { /* private fields */ }Expand description
A multi-channel audio limiter.
Can be useful to prevent clipping on loud audio.
Implementations
Sourceimpl VolumeLimiter
impl VolumeLimiter
Sourcepub fn new(channel_count: u16) -> VolumeLimiter
pub fn new(channel_count: u16) -> VolumeLimiter
Initializes a new audio limiter with a specified audio channel count.
Sourcepub fn limit(&mut self, sample: &mut [f32])
pub fn limit(&mut self, sample: &mut [f32])
Applies the limiting algorithm to the given sample buffer to prevent clipping.
pub fn limit_iter<'a, 'b, T: 'b + Iterator<Item = f32>>( &'a mut self, samples: T, ) -> VolumeLimiterIter<'a, 'b, T> ⓘ