pub struct EnvelopeOptions {
pub attack_curve: EnvelopeCurveType,
pub decay_curve: EnvelopeCurveType,
pub release_curve: EnvelopeCurveType,
}Expand description
Options for the curves of a specific envelope.
Fields
attack_curve: EnvelopeCurveTypeControls the type of curve of the attack envelope stage. See the
documentation of the EnvelopeCurveType enum for available options.
Default: Exponential
decay_curve: EnvelopeCurveTypeControls the type of curve of the decay envelope stage. See the
documentation of the EnvelopeCurveType enum for available options.
Default: Linear
release_curve: EnvelopeCurveTypeControls the type of curve of the release envelope stage. See the
documentation of the EnvelopeCurveType enum for available options.
Default: Linear