pub struct SampleSoundfont { /* private fields */ }Expand description
Represents a sample soundfont to be used within XSynth.
Supports SFZ and SF2 soundfonts.
SFZ specification support (opcodes)
lovel&hivellokey&hikeypitch_keycentervolumepansampledefault_pathloop_modeloop_startloop_endoffsetcutoffresonancefil_veltrackfil_keycenterfil_keytrackfilter_typetuneampeg_startampeg_delayampeg_attackampeg_holdampeg_decayampeg_sustainampeg_release
SF2 specification support
Generators
startAddrsOffsetendAddrsOffsetstartloopAddrsOffsetendloopAddrsOffsetstartAddrsCoarseOffsetendAddrsCoarseOffsetstartloopAddrsCoarseOffsetendloopAddrsCoarseOffsetinitialFilterFcinitialFilterQpandelayVolEnvattackVolEnvholdVolEnvdecayVolEnvsustainVolEnvreleaseVolEnvinstrumentkeyRangevelRangeinitialAttenuationcoarseTunefineTunesampleIDsampleModesoverridingRootKeyscaleTuningexclusiveClasskeynumvelocitykeynumToVolEnvHoldkeynumToVolEnvDecay
Modulators
XSynth intentionally supports a baked subset of SF2 modulators so note-on articulation can be resolved at soundfont load time without adding runtime voice stages. Currently supported:
- sources: key number and note-on velocity
- curves: linear, concave, convex, and switch
- transforms: linear and absolute
- destinations: attenuation, filter cutoff, pan, volume envelope timings, and static pitch offsets
The following SF2 features are intentionally not supported in the runtime engine because they would add significant hot-path and binary-size cost:
- modulation envelope generators and destinations
- modulation LFO / vibrato LFO generators and destinations
- generic CC / aftertouch / pitch-wheel-driven SF2 modulators
- chorus and reverb send behavior
Implementations
Sourceimpl SampleSoundfont
impl SampleSoundfont
Sourcepub fn new(
path: impl Into<PathBuf>,
stream_params: AudioStreamParams,
options: SoundfontInitOptions,
) -> Result<Self, LoadSfError>
pub fn new( path: impl Into<PathBuf>, stream_params: AudioStreamParams, options: SoundfontInitOptions, ) -> Result<Self, LoadSfError>
Loads a new sample soundfont of an unspecified type. The type of the soundfont will be determined from the file extension.
Parameters:
path: The path of the soundfont to be loaded.stream_params: Parameters of the output audio. See theAudioStreamParamsdocumentation for the available options.options: The soundfont configuration. See theSoundfontInitOptionsdocumentation for the available options.
Sourcepub fn new_sfz(
sfz_path: impl Into<PathBuf>,
stream_params: AudioStreamParams,
options: SoundfontInitOptions,
) -> Result<Self, LoadSfzError>
pub fn new_sfz( sfz_path: impl Into<PathBuf>, stream_params: AudioStreamParams, options: SoundfontInitOptions, ) -> Result<Self, LoadSfzError>
Loads a new SFZ soundfont
Parameters:
path: The path of the SFZ soundfont to be loaded.stream_params: Parameters of the output audio. See theAudioStreamParamsdocumentation for the available options.options: The soundfont configuration. See theSoundfontInitOptionsdocumentation for the available options.
Sourcepub fn new_sf2(
sf2_path: impl Into<PathBuf>,
stream_params: AudioStreamParams,
options: SoundfontInitOptions,
) -> Result<Self, Sf2ParseError>
pub fn new_sf2( sf2_path: impl Into<PathBuf>, stream_params: AudioStreamParams, options: SoundfontInitOptions, ) -> Result<Self, Sf2ParseError>
Loads a new SF2 soundfont
Parameters:
path: The path of the SF2 soundfont to be loaded.stream_params: Parameters of the output audio. See theAudioStreamParamsdocumentation for the available options.options: The soundfont configuration. See theSoundfontInitOptionsdocumentation for the available options.